@@ -28,7 +28,7 @@ Moose::Exporter->setup_import_methods(
     as_is => [qw/get_options/],
 );
 
-our $VERSION = version->new('0.3.7');
+our $VERSION = version->new('0.3.8');
 our $EXIT    = 1;
 
 has options => (
@@ -65,6 +65,10 @@ has help_package => (
     is      => 'rw',
     isa     => 'Str',
 );
+has help_packages => (
+    is      => 'rw',
+    isa     => 'HashRef[Str]',
+);
 has helper => (
     is      => 'rw',
     isa     => 'Bool',
@@ -327,9 +331,9 @@ sub process {
     ) {
         if (!$self->sub_command->{$self->cmd}) {
             warn 'Unknown command "' . $self->cmd . "\"!\n";
-            die Getopt::Alt::Exception->new( message => "Unknown command '$self->cmd'" )
+            die Getopt::Alt::Exception->new( message => "Unknown command '$self->cmd'", help => 1 )
                 if !$self->help_package;
-            $self->_show_help(1);
+            $self->_show_help(1, 'Unknown command "' . $self->cmd . "\"!\n");
         }
 
         if ( ref $self->sub_command->{$self->cmd} eq 'ARRAY' ) {
@@ -370,6 +374,9 @@ sub process {
         elsif ( $self->auto_complete && $self->opt->auto_complete ) {
             $self->complete(\@errors);
         }
+        elsif ( $self->sub_command && ! $self->cmd ) {
+            $self->_show_help(1);
+        }
     }
 
     return $self;
@@ -466,7 +473,16 @@ sub _show_help {
     my ($self, $verbosity, $msg) = @_;
 
     my %input;
-    if ( $self->help_package && $self->help_package ne "1" ) {
+    if ( $self->help_packages && $self->cmd ) {
+        my $package = $self->help_packages->{$self->cmd};
+        if ($package) {
+            $package =~ s{::}{/}gxms;
+            $package .= '.pm';
+            require $package;
+            %input = ( -input => $INC{$package} );
+        }
+    }
+    elsif ( $self->help_package && $self->help_package ne "1" ) {
         my $help = $self->help_package;
         if ( !-f $help ) {
             $help  .= '.pm';
@@ -499,7 +515,7 @@ Getopt::Alt - Command line option passing with with lots of features
 
 =head1 VERSION
 
-This documentation refers to Getopt::Alt version 0.3.7.
+This documentation refers to Getopt::Alt version 0.3.8.
 
 =head1 SYNOPSIS
 
@@ -782,6 +798,10 @@ Returns a list of all command line options in the current object.
 
 =head3 C<best_option ()>
 
+=head3 C<complete ()>
+
+Command line auto complete helper
+
 =head1 DIAGNOSTICS
 
 =head1 CONFIGURATION AND ENVIRONMENT
